function finalRad= DCexampleControl(serPort)
% Copyright (C) 2011 Cornell University
% This code is released under the open-source BSD license.  A copy of this
% license should be provided with the software.  If not, email:
% CreateMatlabSim@gmail.com

    % Set constants for this program
    maxDuration = 4*60;  % Max time to allow the program to run (s)

    % Initialize loop variables
    tStart = tic;        % Time limit marker
    
    % Start robot moving
    SetFwdVelAngVelCreate(serPort,0.5,0); % speed = 0.5 (the max), angular vel = 0
    
    % Enter main loop
    while toc(tStart) < maxDuration
        
        % read all of the sensors, see 
        % \Documentation\Fuction Specifications.pdf
        % to learn how to use the values that are returned
        [BumpRight BumpLeft WheDropRight WheDropLeft WheDropCaster ...
            BumpFront]= BumpsWheelDropsSensorsRoomba(serPort);
        
        % consider bumped if the right or left or front bump is hit
        bumped = BumpRight || BumpLeft || BumpFront; % '||' is a logical OR, so hitting any bump sensor makes 'bumped' equal TRUE
        
        % another good function to try is: AngleR = AngleSensorRoomba(serPort)
        
        % drive until hit the wall
        if bumped
            
            % go backwards for a bit, stop for a bit, turn for a bit, stop
            SetFwdVelAngVelCreate(serPort,-0.5,0);
            pause(1);
            SetFwdVelAngVelCreate(serPort,0,0);
            pause(0.1);
            SetFwdVelAngVelCreate(serPort,0,0.2);
            pause(1);
            SetFwdVelAngVelCreate(serPort,0,0);
            pause(0.1);
            
            % continue forwards
            SetFwdVelAngVelCreate(serPort,0.5,0);
        end
        
        % pause a little so code doesn't run too fast
        pause(0.01);
    end
    
    % Specify output parameter
    finalRad = 0;
    
    % Stop robot motion
    v = 0;
    w = 0;
    SetFwdVelAngVelCreate(serPort,v,w)
end

